﻿using Azure;
using bachelorAPI_main.Controllers;
using bachelorAPI_main.Data;
using bachelorAPI_main.DTOs;
using bachelorAPI_main.Handlers;
using bachelorAPI_main.Models;
using bachelorAPI_main.Tests.Controllers;
using bachelorAPI_main.Tests.Base;
using FluentAssertions;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using Mysqlx;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xunit;
using Xunit.Abstractions;
using bachelorAPI_main.Tests.testutils;

namespace bachelorAPI_main.Tests.Controllers
{


    public class FeedbackControllerTest : TestBase
    {
        public FeedbackControllerTest() : base()
        {

        }

        /// <summary>
        /// Passes if statuscode is 200
        /// </summary>
        /// <returns></returns>

        [Fact]
        public async Task DoGet_ReturnOkResponse()
        {
            var context = GetContext();
            TestData.InsertFeedbacks(context);


            var feedbackController = services.GetRequiredService<FeedbackController>();

            IActionResult response = await feedbackController.DoGetFeedbacks();
            OkObjectResult objectResponse = Assert.IsType<OkObjectResult>(response);


            Assert.Equal(StatusCodes.Status200OK, objectResponse.StatusCode);

        }

        /// <summary>
        /// Passes if statuscode is 200
        /// </summary>
        /// <returns></returns>

        [Fact]
        public async Task DoPostTest_ReturnsOkRequest()
        {

            var context = GetContext();
            TestData.InsertCustomers(context);
            TestData.InsertFeedbackCatagory(context);
            TestData.InsertModule(context);
            var feedbackController = services.GetRequiredService<FeedbackController>();

            IActionResult actualResult = await feedbackController.DoPostFeedback(new DTOFeedbackNewRequest()
            {
                CustomerSeq = 10014,
                FeedbackNumber = (FeedbackNumberEnum)2,
                CommentText = null,
                ModuleSeq = 1,
                CategorySeq = 1,
            });

            var res = Assert.IsType<OkObjectResult>(actualResult);


            Assert.Equal(StatusCodes.Status200OK, res.StatusCode);

        }
        /// <summary>
        /// Passes if statuscode is 400
        /// </summary>
        /// <returns></returns>

        [Fact]
        public async Task DoPostTest_ReturnsBadRequest()
        {
            var context = GetContext();
            TestData.InsertCustomers(context);
            TestData.InsertFeedbacks(context);
            TestData.InsertModule(context);

            var feedbackController = services.GetRequiredService<FeedbackController>();

            IActionResult actualResult = await feedbackController.DoPostFeedback(new DTOFeedbackNewRequest()
            {
                FeedbackNumber = (FeedbackNumberEnum)1,
                CommentText = "This is a text",
                ModuleSeq = 1,
                CategorySeq = 1,
            });

            var res = Assert.IsType<BadRequestObjectResult>(actualResult);

            Assert.Equal(StatusCodes.Status400BadRequest, res.StatusCode);
        }

        /// <summary>
        /// Passes if statuscode is 500
        /// </summary>
        /// <returns></returns>
        /// 
        [Fact]
        public async Task DoPostTest_ReturnsInternalServerError()
        {
            var feedbackController = services.GetRequiredService<FeedbackController>();

            IActionResult actualResult = await feedbackController.DoPostFeedback(new DTOFeedbackNewRequest()
            {
                CustomerSeq = 22,
                FeedbackNumber = (FeedbackNumberEnum)1,
                CommentText = "This is a text",
                ModuleSeq = 1,
                CategorySeq = 1,
            });

            ObjectResult objectResponse = Assert.IsType<ObjectResult>(actualResult);

            Assert.Equal(StatusCodes.Status500InternalServerError, objectResponse.StatusCode);
        }






    }
}
