﻿using bachelorAPI_main.DTOs;
using bachelorAPI_main.Handlers;
using Microsoft.AspNetCore.Mvc;
using bachelorAPI_main.Models;
using Microsoft.AspNetCore.Http;


namespace bachelorAPI_main.Controllers
{
    [ApiController]
    [Route("[controller]")]
    [Produces("application/json")]
    public class CustomerController : ControllerBase
    {

        private CustomerHandler _customerHandler;

        public CustomerController(IServiceProvider services)
        {
            _customerHandler = services.GetRequiredService<CustomerHandler>(); ;
        }

        /// <summary>
        /// Retrieves a list of all customers.
        /// </summary>
        /// <remarks>
        /// Retrieves a list of all customers. Should be used when adding new feedback.
        /// </remarks>
        /// <response code="200">Returns a list of customers.</response>
        /// <response code="500">Internal server error.</response>

        [HttpGet]
        public async Task<IActionResult> DoGetCustomers()
        {

            DTOCustomerGetListResponse response = new();

            try
            {
                IList<Customer> customerList = await _customerHandler.GetAllCustomers();
                response.Customers = customerList.Select(s => new DTOCustomerGetResponse

                {
                    CustomerSeq = s.CustomerSeq,
                    CustomerName = s.CustomerName

                }).ToList();

                response.Message = "Successfully retrieved all Customers.";
                return Ok(response);
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                response.Message = "Internal server error.";
                return StatusCode(StatusCodes.Status500InternalServerError, response);
            }
        }
    }
}
