﻿using bachelorAPI_main.DTOs;
using bachelorAPI_main.Handlers;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using System;
using bachelorAPI_main.Models;


namespace bachelorAPI_main.Controllers
{
    [ApiController]
    [Route("[controller]")]
    [Produces("application/json")]
    public class FeedbackCategoryController : ControllerBase
    {

        private FeedbackCategoryHandler _feedbackCategoryHandler;

        public FeedbackCategoryController(IServiceProvider services)
        {
            _feedbackCategoryHandler = services.GetRequiredService<FeedbackCategoryHandler>();
        }


        /// <summary>
        /// Retrieves a list of all feedback categories.
        /// </summary>
        /// <remarks>
        /// Retrieves a list of all feedback categories. Should be used when adding new feedback.
        /// </remarks>
        /// <response code="200">Returns a list of feedback categories.</response>
        /// <response code="500">Internal server error.</response>

        [HttpGet]
        public async Task<IActionResult> DoGetFeedbackCategories()
        {

            DTOGetFeedbackCatagoryListReponse response = new();
            try
            {
                IList<FeedbackCategory> feedbackCategoryList = await _feedbackCategoryHandler.GetAllMFeedbackCatagories();
                response.FeedbackCategories = feedbackCategoryList.Select(s => new DTOGetFeedbackCatagoryReponse

                {
                    FeedbackCategoryName = s.FeedbackCategoryName,
                    FeedbackCategorySeq = s.FeedbackCategorySeq


                }).ToList();

                response.Message = "Successfully retrieved all Feedback categories.";
                return Ok(response);

            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                response.Message = "Internal server error.";
                return StatusCode(StatusCodes.Status500InternalServerError, response);
            }
        }
    }
}

