﻿using bachelorAPI_main.DTOs;
using bachelorAPI_main.Handlers;
using bachelorAPI_main.Models;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;



namespace bachelorAPI_main.Controllers
{
    [ApiController]
    [Route("[controller]")]
    [Produces("application/json")]
    public class ModuleController : ControllerBase
    {
        private ModuleHandler _moduleHandler;


        public ModuleController(IServiceProvider services) { 
        
            _moduleHandler= services.GetRequiredService<ModuleHandler>();

        }

        /// <summary>
        /// Retrieves a list of all active modules.
        /// </summary>
        /// <remarks>
        /// Retrieves a list of all active modules. Should be used when adding new feedback.
        /// </remarks>
        ///  <response code="200">Returns a list of active modules.</response>
        /// <response code="500">Internal server error.</response>

        [HttpGet]
        public async Task<IActionResult> DoGetModules()
        {

            DTOModuleGetListResponse response = new();

            try
            {
                IList<Module> moduleList = await _moduleHandler.GetAllModules();
                response.Modules = moduleList.Select(s => new DTOModuleGetResponse

                {
                    ModuleName = s.ModuleName,
                    ModuleSeq = s.ModuleSeq


                }).ToList();

                response.Message = "Successfully retrieved all Modules.";
                return Ok(response);
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                response.Message = "Internal server error.";
                return StatusCode(StatusCodes.Status500InternalServerError, response);
            }
        }
    }   
}
