﻿using bachelorAPI_main.Data;
using bachelorAPI_main.Models;
using Microsoft.EntityFrameworkCore;

namespace bachelorAPI_main.Handlers
{
    public class CommentHandler 
    {
        private readonly DataContext _db;
        
        public CommentHandler(DataContext db)
        {
            _db = db;   
        }

        /// <summary>
        /// Gets all the comments from the database
        /// </summary>
        /// <param name="id"></param>
        /// <returns>A list of all comments</returns>
        public async Task<List<Comment>> GetAllComments(int? id = null)
        {
            var res = await _db.Comments
                       .Where(c => id == null || c.CommentSeq == id)
                       .ToListAsync();
                   
            return res;
        }


        /// <summary>
        /// Adds a comment to the database
        /// </summary>
        /// <param name="comment"></param>
        /// <returns>The added comment</returns>

        public async Task<Comment> AddComment(Comment comment)
        {
            var result = await _db.AddAsync(comment);

            //_db.Entry(comment).State= EntityState.Modified;

            await _db.SaveChangesAsync();
            _db.ChangeTracker.Clear();

            //return (await GetAllComments(comment.CommentSeq))[0];
            return result.Entity;

        }
       

    }
}
