using bachelorAPI_main;
using bachelorAPI_main.Data;
using bachelorAPI_main.Handlers;
using Google.Protobuf.WellKnownTypes;
using Microsoft.EntityFrameworkCore;
using Microsoft.OpenApi.Models;
using MySql.EntityFrameworkCore.Extensions;
using System.Reflection;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.

builder.Services.AddControllers();
// Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
builder.Services.AddEndpointsApiExplorer();
builder.Services.AddSwaggerGen(options =>
{
options.SwaggerDoc("v1", new OpenApiInfo
{ 
    Version= "v1",
    Title="User statistic API",
    Description = "API for collecting user statistic",
});

    // using System.Reflection;
    var xmlFilename = $"{Assembly.GetExecutingAssembly().GetName().Name}.xml";
    options.IncludeXmlComments(Path.Combine(AppContext.BaseDirectory, xmlFilename));

    options.SchemaFilter<SwaggerSchemaExampleFilter>();
});

builder.Services.AddDbContext<DataContext>(options =>
{
    options.UseSqlServer(builder.Configuration["ConnectionStrings:Default"]);

});


builder.Services.AddScoped<CommentHandler>();
builder.Services.AddScoped<FeedbackHandler>();
builder.Services.AddScoped<ModuleHandler>();
builder.Services.AddScoped<FeedbackCategoryHandler>();
builder.Services.AddScoped<CustomerHandler>();


var app = builder.Build();

// Configure the HTTP request pipeline.
if (app.Environment.IsDevelopment())
{
    app.UseSwagger(
        options =>
        {
            options.RouteTemplate = "api-docs/{documentName}/swagger.json";
        });
       
    app.UseSwaggerUI(options =>
    {
        options.SwaggerEndpoint("/api-docs/v1/swagger.json", "User statistic API");
        options.RoutePrefix = "api-docs";
    });
}
app.UseHttpsRedirection();

app.UseAuthorization();

app.MapControllers();

app.Run();
